<?php

/**
 * This file contains QUI\ERP\CryptoCurrency\EventHandler
 */

namespace QUI\ERP\CryptoCurrency;

use Codenixsv\CoinGeckoApi\CoinGeckoClient;
use QUI;

use function array_filter;
use function strtolower;

/**
 * Class EventHandler
 *
 * @package QUI\ERP\CryptoCurrency
 */
class EventHandler
{
    /**
     * @throws QUI\Database\Exception
     * @throws QUI\Exception
     * @throws \Exception
     */
    public static function onQuiqqerCurrencyImport()
    {
        $client = new CoinGeckoClient();

        try {
            $supportedCoins = $client->coins()->getList();
        } catch (\Exception $exception) {
            QUI\System\Log::addWarning($exception->getMessage());
            return;
        }

        $currencies = QUI\ERP\Currency\Handler::getAllowedCurrencies();

        $isSupported = function ($code) use ($supportedCoins) {
            $code = strtolower($code);

            $result = array_filter($supportedCoins, function ($entry) use ($code) {
                if (strtolower($entry['id']) === $code) {
                    return true;
                }

                if (strtolower($entry['symbol']) === $code) {
                    return true;
                }

                if (strtolower($entry['name']) === $code) {
                    return true;
                }

                return false;
            });

            return !!count($result);
        };

        foreach ($currencies as $Currency) {
            if (!$Currency->autoupdate()) {
                continue;
            }

            if ($Currency->getCode() === 'USD') {
                continue;
            }

            if ($isSupported($Currency->getCode())) {
                QUI\ERP\CryptoCurrency\Import::updateCurrency($Currency->getCode());
            }
        }
    }
}
